## 2020-科技新聞
### TechOrange
### 【比臉書的更可愛！】LINE 推「虛擬人像」，拍張照輕鬆打造專屬 Q 版人偶
| VIEW MORE »
### TechOrange 【你怎麼在天花板上？】Toyota 開發懸吊式機器人幫你打掃洗碗，做完還會自動收納！
| VIEW MORE »
|  | ### TechOrange 【什麼時候換數位身分證？】三縣市 2021 元旦起率先試辦，明年 7 月全面換發！
| VIEW MORE »
### TechOrange 【比 Keras 更好用？】德工程師開發全自動機器學習模型包，不用動手寫任何程式！
| VIEW MORE »
|  | ### TechOrange 為了減緩北極冰層融化，科學家提出大膽計畫：在冰上灑玻璃
| VIEW MORE »
### TechOrange 【完全看不出她是假的！】IKEA 新廣告以電腦繪圖模特兒亮相，打掃煮飯樣樣來
| VIEW MORE »
|  | ### TechOrange Google 推 AI 預測平台服務，開發者可共享機器學習模型啦！
| VIEW MORE »
### TechOrange 【有錢人怎麼想？】億萬富豪不會為錢賣命，驅動他們的是賽局的樂趣
| VIEW MORE »
|  | ### TechOrange 【亞洲玩家請重新訓練肌肉記憶】SONY 終於統一了 PS5 把手，O 是取消鍵、X 是確認鍵！
| VIEW MORE »
### TechOrange 【百萬小學堂線上版】互動問答遊戲 Kahoot! 斥資千萬美金，再拓企業教育市場
| VIEW MORE »
|  | ### TechOrange 【潛艇堡是不是麵包？】SUBWAY 在愛爾蘭被判為「非麵包」，原因：含糖量達 10%！
| VIEW MORE »
### TechOrange 鳥類大腦與人腦的相似度，比學者過去所認知的還要高！
| VIEW MORE »
|  | ### TechOrange 科學家發現新型態的「磁電效應」，有望成為資料儲存的新技術方案
| VIEW MORE »
### TechOrange 衛報、聯合利華 CEO 從疫情學到什麼？麥肯錫報告提出新時代的四大領導方針
| VIEW MORE »
|  | ### TechOrange KPMG 專家分析 104 遭駭：求職資料含金量高，台灣人才成科技戰垂涎目標
| VIEW MORE »
### TechOrange 中小企業 IT 人員心聲：網路穩定好管理、不找麻煩就好！岳峰精密化學尋找高 CP 值無線 AP 之旅
| VIEW MORE »
|  | ### TechOrange 【當 Deepfake 遇到日本工程師】合成藝人的臉販售成人片獲利有無觸法？日警：違反著作權並涉嫌名譽毀損
| VIEW MORE »
### TechOrange 【製造業轉型升級戰】OT 系統雲端、地端資安都要到位！沒有 IT 部門，中小企業也可以輕鬆掌握資訊安全
| VIEW MORE »
|  | ### TechOrange 【原來是在打暗號】Samsonite 和 Google 合推智慧背包，滑背帶就能連手機導航、自拍、釘選地圖！
| VIEW MORE »
### TechOrange 【胃潰瘍新療法？】科學家打造 3D 列印機器人，能進入消化道列印胃壁細胞
| VIEW MORE »
|  | ### TechOrange 【廠房沒建，法人不見】中國面臨「半導體版大躍進」，地方政府百億級投資全打水漂
| VIEW MORE »
### TechOrange 【撥開 AI 轉型迷霧—數據經濟篇 10/7 首播】AI 如何作為企業創新動力，帶領台灣產業突破現狀？
| VIEW MORE »
|  | ### TechOrange FB 可以併購 IG，因為不是競爭者？哥大法學教授揭露企業「玩收購」的秘密！
| VIEW MORE »
### TechOrange 【證實火星有水！】歐洲科學家找到液態水存在證據，超大冰下地底湖登《自然》期刊
| VIEW MORE »
|  | ### TechOrange 【不要舔那裡啊】金頂電池塗上苦味塗層，希望減少幼童誤食
| VIEW MORE »
### iThome
### iThome 內政部數位身分證最新時程出爐！明年7月開始全面換發
| VIEW MORE »
|  | ### iThome 微軟釋出網頁自動化測試工具Playwright for Python
| VIEW MORE »
### iThome 印度開發商不滿Google稅新制揚言跳槽，Google妥協讓當地App分潤30%措施延後半年實施
| VIEW MORE »
|  | ### iThome 資安一周第114期：臺灣2大人力銀行數百萬個資外洩。駭客組織鎖定臺灣等國企業發動間諜攻擊
| VIEW MORE »
### iThome Google發表智慧喇叭Nest Audio，取代Google Home
| VIEW MORE »
|  | ### iThome 臺灣防救災體系10年大改革，災防中心統一災害情資是關鍵
| VIEW MORE »
### iThome 思科收購容器原生安全平臺供應商Portshift
| VIEW MORE »
|  | ### iThome 最新Flutter 1.22支援iOS 14與Android 11新功能
| VIEW MORE »
### iThome 富豪McAfee因推銷加密貨幣獲利被告
| VIEW MORE »
|  | ### iThome GitHub公開儲存庫現可免費啟用程式碼掃描服務
| VIEW MORE »
### iThome WSL2網路流量在部分情況不受VPN保護，直接洩漏至網際網路
| VIEW MORE »
|  | ### iThome IBM開源兩太空AI專案，可預測太空垃圾路徑及強化衛星通訊
| VIEW MORE »
### iThome 微軟即將終止支援Exchange 2010，該升級至Exchange 2013還是2016？
| VIEW MORE »
|  | ### iThome 助臺製造業找出資安的精進方向，工研院新推資安成熟度自評工具
| VIEW MORE »
### iThome 微軟：伊朗駭客正在開採ZeroLogon漏洞
| VIEW MORE »
|  | ### iThome 研究人員揭露以回信當誘餌的新釣魚手法
| VIEW MORE »
### iThome 中國駭客入侵臉書用戶帳號以張貼非法廣告
| VIEW MORE »
|  | ### iThome 電子回收業者Geep非法轉售iPhone與iPad，遭蘋果提告
| VIEW MORE »
### iThome Google發表5G版Pixel 4a與Pixel 5
| VIEW MORE »
|  | ### iThome 臉書眾籌式趨勢預測工具Forecast上線
| VIEW MORE »
### iThome D-Wave開始提供5,000量子位元運算平臺雲端服務
| VIEW MORE »
|  | ### iThome Nvidia推出59美元的AI開發者套件
| VIEW MORE »
### iThome Cloud周報第82期：時隔一個月，Gmail在美東又發生故障事件
| VIEW MORE »
|  | ### iThome 中國駭客利用改造UEFI bootkit攻擊多國官員及NGO成員
| VIEW MORE »
### iThome Google針對OEM業者推出Android漏洞合作夥伴倡議
| VIEW MORE »
|  | ### iThome Eset發現秘密盜取政府資料長達9年的APT駭客XDSpy
| VIEW MORE »
### iThome Slack周一出現傳訊及連線困難
| VIEW MORE »
|  | ### iThome 拍照時啟用「美化」功能有礙心理健康，Google將關閉相機程式的美圖預設
| VIEW MORE »
### iThome Amazon S3加入更多安全與存取控制功能
| VIEW MORE »
|  | ### iThome VMware重構VCF支援新一代網卡SmartNIC，讓vSAN、NSX成獨立處理環境
| VIEW MORE »
### iThome 又傳出335萬求職個資被出售於暗網論壇，1111人力銀行表示已是9年前舊案
| VIEW MORE »
|  | ### iThome Qnap裝置遭AgeLocker勒索軟體鎖定攻擊
| VIEW MORE »
### iThome 微軟聯合18家新創團隊搶攻智慧零售、製造、金融及醫療
| VIEW MORE »
|  | ### iThome Nvidia推出雲端AI視訊串流平臺Maxine
| VIEW MORE »
### iThome 微軟發布適用於VS Code的Edge瀏覽器開發者工具
| VIEW MORE »
|  | ### iThome 最新搭載Google TV功能的Chromecast發布，預計2021年上半支援Stadia
| VIEW MORE »
### iThome Google成立安全小組，專找「高度敏感」App的漏洞
| VIEW MORE »
|  | ### iThome 英國發現華為設備有「影響國家安全」的瑕疵
| VIEW MORE »
### iThome Trickbot殭屍網路遭不明人士襲擊搞破壞
| VIEW MORE »
|  | ### iThome 紐約州推出使用Google、蘋果開發的COVID-19接觸追蹤App
| VIEW MORE »
### iThome MIT以機器學習偵測肺水腫，要助醫生第一時間搶救急性心臟病患
| VIEW MORE »
|  | ### iThome 我的E政府入口網大改版!
| VIEW MORE »
### iThome 一場狗吠火車的數位身分證New eID風險論壇
| VIEW MORE »
|  | ### iThome 瑞士鐘錶公司Swatch集團傳出遭駭客入侵
| VIEW MORE »
### iThome 生活數據新金礦
| VIEW MORE »
|  | ### iThome 彙整全產品AIOT軟體布局，英特爾推出邊緣運算軟體集散中心網站
| VIEW MORE »
### iThome Matrix核心開發商併購開發人員即時通訊平臺Gitter
| VIEW MORE »
|  | ### iThome 臉書開始整併旗下三大通訊平臺，IG與Messenger先行
| VIEW MORE »
### iThome 北美開發者調查：現在負責的程式碼規模是2010年的100倍
| VIEW MORE »
|  | ### iThome Amazon遭踢爆導入倉儲機器人反讓物流中心工傷率高出5成
| VIEW MORE »
### iThome 英國少算逾1.5萬名武漢肺炎確診患者，疑因超過Excel限制
| VIEW MORE »
|  | ### iThome 國內人力銀行傳有592萬筆求職個資外洩，104公告說明，遭公布35筆是2013年舊資料
| VIEW MORE »
### iThome NEC以22億美元收購瑞士金融軟體開發商Avaloq
| VIEW MORE »
|  | ### iThome Google約聘人員控告工作條款禁止爆料
| VIEW MORE »
### iThome 大數據獨角獸Palantir上市首日以9.5美元作收
| VIEW MORE »
|  | ### iThome 微軟發表全新的Surface Laptop Go並更新Surface Pro X
| VIEW MORE »
### iThome 一周大事：Zerologon漏洞攻擊活動出現，AD主機安全拉警報
| VIEW MORE »
|  | ### iThome Windows 10 on Arm今年將可執行x64程式
| VIEW MORE »
### iThome Google媒體授權計畫開跑，News Showcase現身德國與巴西
| VIEW MORE »
|  | ### iThome AI趨勢周報第144期：16支辨識引擎打造數位布片資料庫，臺新創要當紡織界Google Search
| VIEW MORE »
### 數位時代
### Netflix紀錄片《智能社會：進退兩難》劍指社群媒體！Facebook列7大點反駁片中指控
| VIEW MORE »
### 數位時代 跟股癌合作像初戀、折扣打到心會痛！最早「蝦挺買」，眠豆腐揭密Podcast廣告成效
| VIEW MORE »
|  | ### 數位時代 Google攜合作夥伴推動「漏洞修補計畫」，讓Android手機更安全、加速補強破口
| VIEW MORE »
### 數位時代 為何Podcast能讓品牌賣爆？解讀股癌、百靈果、台通的「洗腦大法」
| VIEW MORE »
|  | ### 數位時代 首創用Chatbot買台股、抽股票！國泰「阿發」升級後更強大，怎麼做到模擬人腦思維？
| VIEW MORE »
### 數位時代 Google Pixel 5與Pixel 4a 5G正式亮相！加入超廣角鏡頭，售價15,990元起
| VIEW MORE »
|  | ### 數位時代 蝦皮一連六天開賣口罩，中衛軍綠、潮橘都有，還有國慶紀念款只送不賣！各大通路買法一次看
| VIEW MORE »
### 數位時代 靠Facebook讓營收翻7倍，myBRA解密廣告投放心法，為何9月就要「預熱」雙11？
| VIEW MORE »
|  | ### 數位時代 中芯首度證實禁令成真、已遭美國封殺！還會有更多中國半導體企業被禁嗎？
| VIEW MORE »
### 數位時代 「這面膜跟ETF一樣，不知道買什麼時就買它！」一群金融仔為何被Podcast成功推坑？
| VIEW MORE »
|  | ### 數位時代 Podcast野蠻生長期、追上Spotify腳步！台灣平台業者SoundOn與KKBOX如何布局？
| VIEW MORE »
### 數位時代 【圖解】汎德永業中籤率僅0.26％，抽中現賺13萬！一張圖看它如何連續6年獲利
| VIEW MORE »
|  | ### 數位時代 攜手研華解決企業AI應用痛點，行動貝果如何找到品牌的「轉型標竿」？
| VIEW MORE »
### 數位時代 態度放軟遞出橄欖枝！Google承諾支付300億給新聞發行商，為News Showcase鋪路
| VIEW MORE »
|  | ### 數位時代 「超感」藝術新邏輯！沒聲音與劇本的展覽，觀眾如何化作幽靈、在虛實空間徘徊？
| VIEW MORE »
### 數位時代 又落空？蘋果無線充電板AirPower歷劫歸來，上線時程卻可能又延至明年
| VIEW MORE »
|  | ### 數位時代 遠端自拍、遙控導航都行！Google X LEVI'S再次顛覆時尚，這件夾克還有什麼本領？
| VIEW MORE »
### 數位時代 104、1111會員個資流向暗網，近百萬人身份證、住址全曝光！駭客為何專攻求職網？
| VIEW MORE »
|  | ### 數位時代 從電腦教室到軍方！華碩出動「商用小隊」解決客戶疑難雜症，會有哪些特殊狀況？
| VIEW MORE »
### 數位時代 3D寶貝球悠遊卡回來了、還開放「限時不限量預購」！只有悠遊付會員能搶
| VIEW MORE »
|  | ### 數位時代 數位身分證2021年7月全面換發！內政部派「神秘客」找漏洞，資安問題有解嗎？
| VIEW MORE »
### 數位時代 DigiWave雙十連假高雄登場、「台通」也來助陣！從美食市集到體感戲院，4大展區搶先看
| VIEW MORE »
|  | ### 數位時代 食安危機連環爆、創辦人準備退休！中國火鍋龍頭海底撈股價飆漲背後的3大危機
| VIEW MORE »
### 數位時代 5G應用精彩綻放，我們何妨一試？
| VIEW MORE »
|  | ### 數位時代 虛擬人物正夯！《鬼滅之刃》也推角色產生器、還能加台詞跟招式，步驟一次看
| VIEW MORE »
### 數位時代 百視達、柯達、Nokia跌落科技浪頭下...在「快時代」生存，品牌的必備能力是什麼？
| VIEW MORE »
|  | ### 數位時代 10月6日新增3境外移入案例！分別自美國、法國返台，其中2人同班機，全台累計521例
| VIEW MORE »
### 數位時代 不串API也能用！LINE推「官方帳號分眾+」，標籤功能、個人化選單免費開放
| VIEW MORE »
|  | ### 數位時代 馬斯克狂言：特斯拉年產量在2030年達2千萬輛！10年要飆升50倍，有可能實現嗎？
| VIEW MORE »
### 數位時代 Messenger跟Instagram訊息整合了！聊天不用再切換App，10項新功能一次看
| VIEW MORE »
|  | ### 數位時代 在這個社群時代，為什麼我們仍然需要金曲獎？
| VIEW MORE »
### 數位時代 辨識路況、圖資自動翻新！台大教授利用「車輛之眼」，打造即時街景夢
| VIEW MORE »
|  | ### 數位時代 工研院連續13年奪下科技產業奧斯卡，有兩大研發亮點！為何都聚焦在電池？
| VIEW MORE »
### 數位時代 一則貼文創造破萬分享，社群行銷常用的「迷因」究竟是什麼？三大特色一次了解
| VIEW MORE »
|  | ### 數位時代 庫克任期剩一年！蘋果董事會祭出32億股票獎勵，盼他留任CEO到2025年
| VIEW MORE »
### 數位時代 2020亞洲傑出企業榜單出爐、台灣15間上榜！台積電蟬聯半導體冠軍，這家得到最大獎
| VIEW MORE »
|  | ### 數位時代 IBM科技預測報告「5 in 5」出爐！藍色巨人要用AI與量子技術做些什麼？
| VIEW MORE »
### 數位時代 曾是祖克伯的親密戰友！Asana創辦人為何毅然離開Facebook溫柔鄉，醉心打造專案軟體工具？
| VIEW MORE »
|  | ### 數位時代 全家靠Line帳號綁住社區型鐵粉、萊爾富打造全新購物平台，為何超商都狂推「虛擬二樓」？
| VIEW MORE »
### INSIDE
### 未來已經到來，智慧城市在國內的成果，遍及交通、教育、醫療、安全等眾多面向；隨著資通訊及科技的不斷進展，智慧城市有更多精彩可期的應用，將逐一實現在日常生活中，我們將陸續為您介紹。
| VIEW MORE »
### INSIDE 數位轉型已成台灣企業的重要目標，Dell Technologies 以連續 11 季 (2017 Q3~2020 Q1)由 IDC評比為 HCI 領導廠商的角色，持續創新，致力為企業提供最合適的 IT 解決方案，達到多元化定位的轉型！
| VIEW MORE »
|  | ### INSIDE Google 購物開放亞太區免費刊登！為了幫助受疫情影響的零售店家，，台灣也包含在免費刊登的範圍內。
| VIEW MORE »
### INSIDE Google 對 VR 的發展重心也從硬體轉到手機 AR 應用程式以及 3D 繪畫工具如 Tilt Brush 等應用程式面上， 但還是會以開源的方式支援 Cardboard。
| VIEW MORE »
|  | ### INSIDE 今年前 8 月積體電路出口金額達 760.22 億美元，創歷年同期新高，占出口比重也上衝至 35%，寫下歷史同期最高。疫情肆虐下，台灣出口仍能保有成長動能，積體電路扮演關鍵角色。
| VIEW MORE »
### INSIDE 特斯拉週五發布了交車和產量最新結果，第三季交付電動汽車數字，遠高於華爾街預期的 12 萬台。
| VIEW MORE »
|  | ### INSIDE 稍早由外媒記者 Casey Michel 發現這項更新 Instagram 也開始置入「state-controlled media」標籤，部分帳戶包括：Redfish、 In the Now 擁有上萬追隨者的專頁，已經被標記由俄羅斯政府運作。
| VIEW MORE »
### INSIDE 即將開業的純網銀「將來銀行」，如何運用科技幫助金融產業創新，同時讓消費體驗更加理想？首先要談的還是資安，唯有完善的資安基礎，才能落實金融創新。
| VIEW MORE »
|  | ### INSIDE 華碩電腦大方祭出 3 大開學季活動，即日起至 9 月 30 日以前，除了購買指定機種抽大獎之外，到光華商場一樓攤位現場體驗活動，集滿 3 個闖關手章、填寫問卷，即可現抽限量好禮。
| VIEW MORE »
### INSIDE 中國目前為電動車電池鎳、鈷礦的主要生產國，美國為降低過度依賴中國供應，傳已斥資 2500 萬美元入股英國礦商佈局。
| VIEW MORE »
|  | ### INSIDE 全球醫療照護產業正面臨前所未有的變革，大數據、人工智慧、物聯網裝置、資料互通及醫療場域去中心化等技術，正在顛覆既有的銀髮醫療及關懷體系。科技供應鏈既廣且深的台灣，面對即將來臨的超高齡社會，很有機會透過數位科技的整合與創新，成為全球銀髮樂活典範，在食衣醫住行育樂等不同領域，更全面且永續的維護每位銀髮國民的福祉。
| VIEW MORE »
### INSIDE 身為全球最大社群網路業者也是本片抨擊最用力的對象，Facebook 最近特地發文列出七點，大力駁斥《智能社會：進退兩難》的論點。
| VIEW MORE »
|  | ### INSIDE 若遭定罪，John McAfee 可能會面臨五年以上的有期徒刑，他涉嫌違法行銷 ICO，並從中獲利市值超過 2,310 萬美元的虛擬貨幣。
| VIEW MORE »
### INSIDE OVO 無框電視 K1 整合了智慧電視盒、投影機以及專用 OS 為一身，國內外串流影音與 OTT 也一口氣整合在內！
| VIEW MORE »
|  | ### INSIDE 唯有建立全方位觀點與全面性的威脅防護機制，才能採取最迅速、最精準的對策，主動出擊以因應當前及未來持續演變進化的資安威脅。
| VIEW MORE »
### INSIDE 但少了 Apple 跟 Amazon，這次主題將聚焦美國《通訊法》第 230 條所帶來的網路平台法律免責權。
| VIEW MORE »
|  | ### INSIDE 科學家呼籲，應改善資料同化（data assimilation）與氣象預報模型，並因應 5G 系統在時間、空間和頻率的動態變化進行調整。
| VIEW MORE »
### INSIDE Podcast 進入門檻低，賺錢的節目卻沒多少。究竟以媒體廣告市場第一線的廣告代理商角度來看，Podcast 有哪些可能性？又有哪些潛力商業模式？
| VIEW MORE »
|  | ### INSIDE 徐國勇說數位身分證將在澎湖縣、新竹市及新北市先小規模試行，不過媒體爆料東元未獲 Intergraf 認證疑雲，不知是否會為換發再添變數？
| VIEW MORE »
### INSIDE 外洩資訊鉅細靡遺，包括求職者身分證字號、姓名、出生日期、手機、電子信箱等，104 表示疑為 2013 年遭非法入侵的外洩資料，已向調查局報案。
| VIEW MORE »
|  | ### INSIDE 目前 CSK&D 已經開始蒐集相關證詞，並且透過論壇網站呼籲受到此問題影響的玩家可在 10 月 16 日以前提供相關影片作為證據，以利後續在法院上與任天堂對質。
| VIEW MORE »
### INSIDE 用協作軟體遠距工作時，你容易被干擾、消化不了一堆資訊、討厭不斷被要求參加線上會議、擔心敏感文件不慎外洩嗎？ 或許可以來看看微軟的設計理念如何解決這些問題。
| VIEW MORE »
|  | ### INSIDE 全球各疫苗廠今年全年供貨量年增逾 15%，仍供不應求，其中，歐洲政府、藥廠首度來台詢問流感疫苗。
| VIEW MORE »
### INSIDE 傳統產業數位轉型已是目前趨勢，本次以資策會輔導的巨全金屬為例，藉由找痛點、提解方、轉文化三部曲，讓傳統產業藉由科技的注入，提升營運績效、建立獨特企業文化，打造企業軟硬實力，開創數位新生命。
| VIEW MORE »
|  | ### INSIDE 近來興起一股在家附近或是國內度過悠閒假期的Staycation（Stay+vacation）風潮，為過往的連假消費趨勢帶來不一樣面貌，電商免出門、免搬貨的特色更因此受到宅度假消費者的青睞，滿足各種需求。
| VIEW MORE »
### INSIDE 財團法人資訊工業策進會科技法律研究所（資策會科法所）於今（109）年初即開始辦理「新創法律健身坊」課程，如今已進入第四訓，給予新創團隊許多協助與建議。
| VIEW MORE »
|  | ### INSIDE 金管會最新統計第 3 季可望正式突破 3,000 億元大關，且跟去年同期相比，呈現倍數躍增，年增近 156%！
| VIEW MORE »
### INSIDE 「大家都很理解「線上問卷」是什麼。不過缺點也是顯而易見地，我每次不管對朋友、客戶、甚至投資人的 Pitch，我最常被挑戰的問題就是： 你們跟 Google Form 和 SurveyMonkey 有什麼不一樣？」
| VIEW MORE »
|  | ### INSIDE 資安威脅早已不是制式化的一成不變，微軟讓安全深化成為每項產品的原生DNA，從開發階段就進行演練及優化，主動防堵潛在的資安漏洞，並確保與時俱進的防禦力，打造主動防禦的守備空間。
| VIEW MORE »
### INSIDE 「 OSIM uDream 5 感養身椅」以超群科技首創「 AI 壓力監測」，匯集視覺、聽覺、嗅覺、味覺及觸覺 5 感體驗打造「個人化」紓壓按摩程式，不只養身、更養心。
| VIEW MORE »
|  | ### INSIDE 華爾街出現亞馬遜的新大多頭。
| VIEW MORE »
### INSIDE Emoji 更新了！不只是生病了才要戴口罩，疫情下戴口罩更是防疫重點之一，戴口罩的表情也從苦瓜臉變成了笑臉。
| VIEW MORE »
|  | ### INSIDE 銓鍇國際CKmates如何透過混合雲一條龍服務來協助企業解決數位轉型的困難，並且保護企業珍貴的數據資產，確保企業數據在雲端地端運作無虞。
| VIEW MORE »
### INSIDE 防疫期間，直播可以作為品牌主的新溝通工具。透過成果行銷的直播廣告與程序化購買策略，讓 Live Streaming Ads 傳遞品牌價值、掌握流量、理解粉絲，進而創造直播佳績。
| VIEW MORE »
|  | ### INSIDE 投資銀行和銀行有什麼不一樣，又綠色投資銀行要符合哪些條件呢？
| VIEW MORE »
### INSIDE Instagram 6 日將歡慶 10 週年，原本填滿這個社群平台的夕陽餘暉藝術照、賞心悅目冰淇淋照，隨著社會公義示威、氣候危機與疫情延燒，被更多的示威活動內容取代。
| VIEW MORE »
|  | ### INSIDE 美國總統川普確診武漢肺炎之後，有不少反對者在推特上詛咒或是期待川普死於武漢肺炎。推特則提醒使用者，這並不符合推特的政策。
| VIEW MORE »
### INSIDE 打造金融科技不能只靠技術。玉山導入 MLOps 文化，讓機器學習不再是純粹的數據領域，而是能讓工程與營運攜手運作，讓團隊走得更快、更遠。
| VIEW MORE »
|  | ### INSIDE 什麼樣的產品才是符合環境友善的定義的綠色產品？
| VIEW MORE »
### INSIDE 但退出 F1後，HONDA 現在也沒有轉戰電動方程式（Formula E）或其他電動車賽事的打算。
| VIEW MORE »
|  | ### INSIDE iOS 14 其中六項問題歸類為與活動、健康及健身 App 有關，還有一項更嚴重的問題，就是「iPhone 和 Apple Watch 耗電量增加」。
| VIEW MORE »
### INSIDE 法拉第曾經是炒作最多的電動汽車新創公司之一，燒掉了 20 億美元現金。
| VIEW MORE »
|  | ### INSIDE 桃園市政府在今年9月底提出永續發展目標（SDGs）的地方自願檢視報告（VLR）。在實踐永續發展的路上，市府積極將物聯網應用於日常生活，改變災害搶救方式保障民眾生命，在教育及青創方面打造智慧城市並持續往永續發展的方向邁進。
| VIEW MORE »
### INSIDE NVIDIA 今年 GTC 主題其實某種程度上來說很簡單：AI，AI，還是 AI！
| VIEW MORE »
|  | ### INSIDE 財團法人資訊工業策進會今年以「數位孿生品質決策支援系統（ PDSS ）」勇奪美國 R&D 全球百大科技研發獎。
| VIEW MORE »